//
//  ProfileEdit.swift
//  ArkitDoushiQi
//
//  Created by Johan LACHENAL, Louis DUFOUR on 28/05/2024.
//

import SwiftUI

struct ProfileEdit: View, KeyboardReadable {
    let color: Color
    let profileWidth: CGFloat
    let profileHeight: CGFloat
    let defaultImage: Image
    let imageTextChange: LocalizedStringKey
    let playerNameKey: LocalizedStringKey
    @Binding var playerName: String
    @State private var keyboardHeight: CGFloat = 0
    @State private var isKeyboardVisible: Bool = false

    var body: some View {
        VStack(alignment: .leading) {
            EditImageComponent(
                color: color,
                profileWidth: profileWidth,
                profileHeight: profileHeight,
                defaultImage: defaultImage,
                imageTextChange: imageTextChange
            ).padding(.horizontal)
            
            EditTextComponent(explanation: playerNameKey, name: $playerName)
                .padding(.horizontal)
        }
        .padding(.bottom, isKeyboardVisible ? keyboardHeight : 0)
        .animation(.easeOut(duration: 0.3), value: keyboardHeight)
        .onReceive(keyboardPublisher) { height in
            withAnimation {
                self.keyboardHeight = height
                self.isKeyboardVisible = height > 0
            }
        }
    }
}

struct ProfileEdit_Previews: PreviewProvider {
    static var previews: some View {
        ProfileEdit(color: Color(.red),
                    profileWidth: 100,
                    profileHeight: 100,
                    defaultImage: Image("profil"),
                    imageTextChange: "Changer l'avatar",
                    playerNameKey: "Nom du Joueur 1",
                    playerName: .constant("Joueur 1")
        )
    }
}

